@@ -52,8 +52,12 @@ static INTRINSICS0: phf::Map<&'static str, NamedFn0> = phf_map! {
 static INTRINSICS1: phf::Map<&'static str, (NamedFn1, ArgType)> = phf_map! {
     "error" => (NamedFn1 { name: "error", func: error1 }, ArgType::Value),
     "has" => (NamedFn1 { name: "has", func: has }, ArgType::Value),
-    "in" => (NamedFn1 { name: "in", func: |c, i| has(i, c) }, ArgType::Value),
+    "in" => (NamedFn1 { name: "in", func: |i, c| has(c, i) }, ArgType::Value),
     "contains" => (NamedFn1 { name: "contains", func: contains }, ArgType::Value),
+    "inside" => (NamedFn1 { name: "inside", func: |i, c| contains(c, i) }, ArgType::Value),
+    "indices" => (NamedFn1 { name: "indices", func: indices }, ArgType::Value),
+    "startswith" => (NamedFn1 { name: "startswith", func: starts_with }, ArgType::Value),
+    "endswith" => (NamedFn1 { name: "endswith", func: ends_with }, ArgType::Value),
     "delpaths" => (NamedFn1 { name: "delpaths", func: path::del_paths }, ArgType::Value),
 };
 static INTRINSICS2: phf::Map<&'static str, (NamedFn2, ArgType, ArgType)> = phf_map! {
@@ -234,3 +238,45 @@ pub(crate) fn group_by(context: Value) -> Result<Value> {
         .collect_vec();
     Ok(Array::from_vec(arr).into())
 }
+
+fn indices(context: Value, s: Value) -> Result<Value> {
+    let ret = match (context, s) {
+        (Value::String(lhs), Value::String(rhs)) => Array::from_vec(
+            lhs.match_indices(rhs.as_ref())
+                .map(|(pos, _)| Value::Number(pos.into()))
+                .collect(),
+        )
+        .into(),
+        (Value::Array(lhs), Value::Array(rhs)) => Array::from_vec(
+            lhs.windows(rhs.len())
+                .enumerate()
+                .filter(|(_, lhs)| lhs.iter().eq(rhs.iter())) // TODO: NaN
+                .map(|(pos, _)| Value::Number(pos.into()))
+                .collect(),
+        )
+        .into(),
+        (Value::Array(lhs), rhs) => Array::from_vec(
+            lhs.iter()
+                .enumerate()
+                .filter(|(_, v)| *v == &rhs) // TODO: NaN
+                .map(|(pos, _)| Value::Number(pos.into()))
+                .collect(),
+        )
+        .into(),
+        (context, _) => return Err(QueryExecutionError::InvalidArgType("indices", context)),
+    };
+    Ok(ret)
+}
+
+fn starts_with(context: Value, s: Value) -> Result<Value> {
+    match (context, s) {
+        (Value::String(lhs), Value::String(rhs)) => Ok(lhs.starts_with(rhs.as_ref()).into()),
+        (context, _) => Err(QueryExecutionError::InvalidArgType("startswith", context)),
+    }
+}
+fn ends_with(context: Value, s: Value) -> Result<Value> {
+    match (context, s) {
+        (Value::String(lhs), Value::String(rhs)) => Ok(lhs.ends_with(rhs.as_ref()).into()),
+        (context, _) => Err(QueryExecutionError::InvalidArgType("endswith", context)),
+    }
+}
\ No newline at end of file
